API Reference
=============

.. automodule:: referencing
   :members:
   :undoc-members:
   :imported-members:

.. autoclass:: referencing._core.Resolver
   :members:
   :undoc-members:

.. autoclass:: referencing._core.Specification
   :members:
   :undoc-members:


Submodules
----------

referencing.jsonschema
^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: referencing.jsonschema
   :members:
   :undoc-members:


referencing.typing
^^^^^^^^^^^^^^^^^^

.. automodule:: referencing.typing
   :members:
   :undoc-members:
